==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/SBClient.java <==
package net.invictusslayer.slayersbeasts.client;

import net.invictusslayer.slayersbeasts.client.model.*;
import net.invictusslayer.slayersbeasts.client.renderer.*;
import net.invictusslayer.slayersbeasts.registries.SBEntities;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_5601;
import net.minecraft.class_5607;
import net.minecraft.class_5617;
import java.util.function.BiConsumer;
import java.util.function.Supplier;

public class SBClient {
	public static void registerModelLayers(BiConsumer<class_5601, Supplier<class_5607>> consumer) {
		consumer.accept(MantisModel.LAYER_LOCATION, MantisModel::createBodyLayer);
		consumer.accept(AntWorkerModel.LAYER_LOCATION, AntWorkerModel::createBodyLayer);
		consumer.accept(AntSoldierModel.LAYER_LOCATION, AntSoldierModel::createBodyLayer);
		consumer.accept(AntQueenModel.LAYER_LOCATION, AntQueenModel::createBodyLayer);
		consumer.accept(AntCargoModel.LAYER_LOCATION, AntCargoModel::createCargoLayer);
		consumer.accept(WitherSpiderModel.LAYER_LOCATION, WitherSpiderModel::createBodyLayer);
		consumer.accept(TyrachnidModel.LAYER_LOCATION, TyrachnidModel::createBodyLayer);
		consumer.accept(DamselflyModel.LAYER_LOCATION, DamselflyModel::createBodyLayer);
		consumer.accept(EntMediumModel.LAYER_LOCATION, EntMediumModel::createBodyLayer);
		consumer.accept(WuduModel.LAYER_LOCATION, WuduModel::createBodyLayer);
		consumer.accept(SporetrapModel.LAYER_LOCATION, SporetrapModel::createBodyLayer);
		consumer.accept(IrkModel.LAYER_LOCATION, IrkModel::createBodyLayer);
	}

	public static void registerRenderers(BiConsumer<class_1299<? extends class_1297>, class_5617> consumer) {
		consumer.accept(SBEntities.MANTIS.get(), MantisRenderer::new);
		consumer.accept(SBEntities.ANT_WORKER.get(), AntWorkerRenderer::new);
		consumer.accept(SBEntities.ANT_SOLDIER.get(), AntSoldierRenderer::new);
		consumer.accept(SBEntities.ANT_QUEEN.get(), AntQueenRenderer::new);
		consumer.accept(SBEntities.WITHER_SPIDER.get(), WitherSpiderRenderer::new);
		consumer.accept(SBEntities.TYRACHNID.get(), TyrachnidRenderer::new);
		consumer.accept(SBEntities.DAMSELFLY.get(), DamselflyRenderer::new);
		consumer.accept(SBEntities.ENT_MEDIUM.get(), EntMediumRenderer::new);
		consumer.accept(SBEntities.WUDU.get(), WuduRenderer::new);
		consumer.accept(SBEntities.SPORETRAP.get(), SporetrapRenderer::new);
		consumer.accept(SBEntities.IRK.get(), IrkRenderer::new);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/SBClient.java <==
package net.invictusslayer.slayersbeasts.client;

import net.invictusslayer.scabbard.world.level.WoodFamily;
import net.invictusslayer.slayersbeasts.client.model.*;
import net.invictusslayer.slayersbeasts.client.renderer.*;
import net.invictusslayer.slayersbeasts.registries.SBEntities;
import net.invictusslayer.slayersbeasts.world.level.block.SBWoodFamily;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1690;
import net.minecraft.class_554;
import net.minecraft.class_5601;
import net.minecraft.class_5607;
import net.minecraft.class_5617;
import net.minecraft.class_7264;
import net.minecraft.class_881;
import java.util.function.BiConsumer;
import java.util.function.Supplier;

public class SBClient {
	public static void registerModelLayers(BiConsumer<class_5601, Supplier<class_5607>> consumer) {
		consumer.accept(MantisModel.LAYER_LOCATION, MantisModel::createBodyLayer);
		consumer.accept(AntWorkerModel.LAYER_LOCATION, AntWorkerModel::createBodyLayer);
		consumer.accept(AntSoldierModel.LAYER_LOCATION, AntSoldierModel::createBodyLayer);
		consumer.accept(AntQueenModel.LAYER_LOCATION, AntQueenModel::createBodyLayer);
		consumer.accept(AntCargoModel.LAYER_LOCATION, AntCargoModel::createCargoLayer);
		consumer.accept(WitherSpiderModel.LAYER_LOCATION, WitherSpiderModel::createBodyLayer);
		consumer.accept(TyrachnidModel.LAYER_LOCATION, TyrachnidModel::createBodyLayer);
		consumer.accept(DamselflyModel.LAYER_LOCATION, DamselflyModel::createBodyLayer);
		consumer.accept(EntMediumModel.LAYER_LOCATION, EntMediumModel::createBodyLayer);
		consumer.accept(WuduModel.LAYER_LOCATION, WuduModel::createBodyLayer);
		consumer.accept(SporetrapModel.LAYER_LOCATION, SporetrapModel::createBodyLayer);
		consumer.accept(IrkModel.LAYER_LOCATION, IrkModel::createBodyLayer);

		SBWoodFamily.getAllFamilies().forEach(family -> {
			if (family.getBoatLayer(false) != null) consumer.accept(family.getBoatLayer(false), class_554::method_31985);
			if (family.getBoatLayer(true) != null) consumer.accept(family.getBoatLayer(true), class_554::method_62066);
		});
	}

	public static void registerRenderers(BiConsumer<class_1299<? extends class_1297>, class_5617> consumer) {
		consumer.accept(SBEntities.MANTIS.get(), MantisRenderer::new);
		consumer.accept(SBEntities.ANT_WORKER.get(), AntWorkerRenderer::new);
		consumer.accept(SBEntities.ANT_SOLDIER.get(), AntSoldierRenderer::new);
		consumer.accept(SBEntities.ANT_QUEEN.get(), AntQueenRenderer::new);
		consumer.accept(SBEntities.WITHER_SPIDER.get(), WitherSpiderRenderer::new);
		consumer.accept(SBEntities.TYRACHNID.get(), TyrachnidRenderer::new);
		consumer.accept(SBEntities.DAMSELFLY.get(), DamselflyRenderer::new);
		consumer.accept(SBEntities.ENT_MEDIUM.get(), EntMediumRenderer::new);
		consumer.accept(SBEntities.WUDU.get(), WuduRenderer::new);
		consumer.accept(SBEntities.SPORETRAP.get(), SporetrapRenderer::new);
		consumer.accept(SBEntities.IRK.get(), IrkRenderer::new);

		SBWoodFamily.getAllFamilies().forEach(family -> {
			if (family.getBoatLayer(false) != null) consumer.accept((class_1299<class_1690>) family.get(WoodFamily.Variant.BOAT).get(), context -> new class_881(context, family.getBoatLayer(false)));
			if (family.getBoatLayer(true) != null) consumer.accept((class_1299<class_7264>) family.get(WoodFamily.Variant.CHEST_BOAT).get(), context -> new class_881(context, family.getBoatLayer(true)));
		});
	}
}
